@@ -50,29 +50,19 @@ def execute_commit(sql_query):
 
 def execute_row_factory(sql_query):
     connection = sqlite3.connect(DATABASE_FILE)
-    connection.row_factory = lambda cursor, row: row[0]
+    # connection.row_factory = lambda cursor, row: row[0]
+    connection.row_factory = sqlite3.Row
     cursor = connection.cursor()
     result = cursor.execute(sql_query)
-    result = list(result)
+    # result = list(result)
     cursor.close()
     connection.close()
+    print(result)
     return result
 
 
-def get_manager_names(season):
-    query_string = '''
-        SELECT   manager_id,
-                 manager_name
-        FROM     manager
-        WHERE    season == {}
-        ORDER BY manager_id ASC;
-    '''.format(season)
-    result = execute_row_factory(query_string)
-    return result
-
-
-def matchup_history(manager_name, manager_elo, opponent_name, opponent_elo, display=True):
-    class WeeklyMatchupHistory:
+def matchup_history(manager_name, opponent_name, display=True):
+    class MatchupHistory:
         def __init__(self):
             self.manager_name = manager_name
             self.opponent_name = opponent_name
@@ -81,10 +71,6 @@ def matchup_history(manager_name, manager_elo, opponent_name, opponent_elo, disp
             self.manager_wins = 0
             self.opponent_wins = 0
             self.matchup_history = None
-            self.manager_elo = manager_elo
-            self.opponent_elo = opponent_elo
-
-    wmh = WeeklyMatchupHistory()
 
     query_string = '''
         SELECT  season,
@@ -95,35 +81,25 @@ def matchup_history(manager_name, manager_elo, opponent_name, opponent_elo, disp
                 result
         FROM    schedule
         WHERE   manager_name = "{}" AND opponent_name = "{}"
-    '''.format(wmh.manager_name, wmh.opponent_name)
+    '''.format(manager_name, opponent_name)
     result = execute_sqlite(query_string)
 
+    mh = MatchupHistory()
+
     df = pd.DataFrame(result, columns=['season', 'Manager', 'Opponent', 'Manager Score', 'Opponent Score', 'Result'])
-
-    wmh.matchup_history = df
-    wmh.manager_avg_score = df['Manager Score'].mean()
-    wmh.opponent_avg_score = df['Opponent Score'].mean()
+    mh.manager_avg_score = df['Manager Score'].mean()
+    mh.opponent_avg_score = df['Opponent Score'].mean()
 
     try:
-        wmh.manager_wins = df.Result.value_counts().W
+        mh.manager_wins = df.Result.value_counts().W
     except AttributeError:
-        wmh.manager_wins = 0
+        mh.manager_wins = 0
 
     try:
-        wmh.opponent_wins = df.Result.value_counts().L
+        mh.opponent_wins = df.Result.value_counts().L
     except AttributeError:
-        wmh.opponent_wins = 0
-    if display is True:
-        print(df.to_string(index=False))
-
-        print("\nCurrently, {} has a rank of {} and {} has a rank of {}. \
-            ".format(wmh.manager_name, wmh.manager_elo, wmh.opponent_name, wmh.opponent_elo))
-        print("The current record between {} and {} is {} - {}. \
-            ".format(wmh.manager_name, wmh.opponent_name, wmh.manager_wins, wmh.opponent_wins))
-        print("The average score between {} and {} is {:0.2f} - {:0.2f}.\
-            ".format(wmh.manager_name, wmh.opponent_name, wmh.manager_avg_score, wmh.opponent_avg_score))
-        print("*********************************************************************")
-    return wmh
+        mh.opponent_wins = 0
+    return mh
 
 
 def get_manager_score_history(manager_name):
